@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: displays a single alert   
@@ -31,23 +32,16 @@
 
    // Check role out and redirect if needed -- Kevin
   $roleneeded = 10000;
+  $payload = FALSE;
+  $offset  = 0;
   $BUser = new BaseUser();
   if (($BUser->hasRole($roleneeded) == 0) && ($Use_Auth_System == 1))
-  {
-    header("Location: ". $BASE_urlpath . "/index.php");
-  }
+    base_header("Location: ". $BASE_urlpath . "/index.php");
 
   # set cookie for packet display
-  if ($_GET[asciiclean] == 1)
-  {
-    setcookie('asciiclean', 'clean');
-  }
-  
-  if ( isset($_GET[asciiclean]) && ($_GET[asciiclean] == 0) )
-  {
-    setcookie('asciiclean', 'normal');
-  }
-  
+  if (isset($_GET['asciiclean'])) {
+      1 == $_GET['asciiclean'] ? setcookie('asciiclean', 'clean') : setcookie('asciiclean', 'normal');   
+  }  
 
 function PrintCleanURL()
 {
@@ -55,18 +49,18 @@ function PrintCleanURL()
   $query = CleanVariable($_SERVER["QUERY_STRING"], VAR_PERIOD | VAR_DIGIT | VAR_PUNC | VAR_LETTER);
   $sort_order=ImportHTTPVar("sort_order", VAR_LETTER | VAR_USCORE);
 
-  if ( ($_GET[asciiclean] == 1) || ( ($_COOKIE["asciiclean"] == "clean") && (!isset($_GET[asciiclean])) ) )
+  if ( (isset($_GET['asciiclean']) && $_GET['asciiclean'] == 1) || ( isset($_COOKIE['asciiclean']) && ($_COOKIE['asciiclean'] == "clean") && (!isset($_GET['asciiclean'])) ) )
   {
     //create link to non-cleaned payload display
     $url = '<center><a href="base_qry_alert.php?'.$query;
-    $url.= '&sort_order='.$sort_order.'&asciiclean=0">'._QANORMALD.'</a></center>';
+    $url.= '&amp;sort_order='.$sort_order.'&amp;asciiclean=0">'._QANORMALD.'</a></center>';
     return $url;
   }
   else
   {
     //create link to cleaned payload display
     $url = '<center><a href="base_qry_alert.php?'.$query;
-    $url.= '&sort_order='.$sort_order.'&asciiclean=1">'._QAPLAIND.'</a></center>';
+    $url.= '&amp;sort_order='.$sort_order.'&amp;asciiclean=1">'._QAPLAIND.'</a></center>';
     return $url;
   }
   
@@ -75,31 +69,32 @@ function PrintCleanURL()
 function PrintBinDownload($db, $cid, $sid){
 // Offering a URL to a download possibility:
     	$query = CleanVariable($_SERVER["QUERY_STRING"], VAR_PERIOD | VAR_DIGIT | VAR_PUNC | VAR_LETTER);
-	if ( ($_GET[asciiclean] == 1) || ( ($_COOKIE["asciiclean"] == "clean") && (!isset($_GET[asciiclean])) ) ){
+	if ( isset($_GET['asciiclean']) && ($_GET['asciiclean'] == 1) || ( (isset($_COOKIE['asciiclean']) && $_COOKIE['asciiclean'] == "clean") && (!isset($_GET['asciiclean'])) ) ){
 		$url = '<center><a href="base_payload.php?'.$query;
-		$url.= '&download=1&cid='.$cid.'&sid='.$sid.'&asciiclean=1">Download of Payload</a></center>';
+		$url.= '&amp;download=1&amp;cid='.$cid.'&amp;sid='.$sid.'&amp;asciiclean=1">Download of Payload</a></center>';
 	} else {
 		$url = '<center><a href="base_payload.php?'.$query;
-		$url.= '&download=1&cid='.$cid.'&sid='.$sid.'&asciiclean=0">Download of Payload</a></center>';
+		$url.= '&amp;download=1&amp;cid='.$cid.'&amp;sid='.$sid.'&amp;asciiclean=0">Download of Payload</a></center>';
 	}
 	return $url;
 }
 
 function PrintPcapDownload($db, $cid, $sid){
-// If we have FLoP extended database offer a URL to download in pcap format:
 
-        if ( !in_array("pcap_header", $db->DB->MetaColumnNames('data')) ||
-             !in_array("data_header", $db->DB->MetaColumnNames('data'))) {
-		return;
-	}
+   if ( !in_array("pcap_header", $db->DB->MetaColumnNames('data')) ||
+        !in_array("data_header", $db->DB->MetaColumnNames('data'))) {
+      $type = 3;
+   } else {
+      $type = 2;
+   }
 
-    	$query = CleanVariable($_SERVER["QUERY_STRING"], VAR_PERIOD | VAR_DIGIT | VAR_PUNC | VAR_LETTER);
-	if ( ($_GET[asciiclean] == 1) || ( ($_COOKIE["asciiclean"] == "clean") && (!isset($_GET[asciiclean])) ) ){
+   $query = CleanVariable($_SERVER["QUERY_STRING"], VAR_PERIOD | VAR_DIGIT | VAR_PUNC | VAR_LETTER);
+	if ( (isset($_GET['asciiclean']) && $_GET['asciiclean'] == 1) || ( isset($_COOKIE['asciiclean']) && ($_COOKIE["asciiclean"] == "clean") && (!isset($_GET['asciiclean'])) ) ){
 		$url = '<center><a href="base_payload.php?'.$query;
-		$url.= '&download=2&cid='.$cid.'&sid='.$sid.'&asciiclean=1">Download in pcap format</a></center>';
+		$url.= '&amp;download='.$type.'&amp;cid='.$cid.'&amp;sid='.$sid.'&amp;asciiclean=1">Download in pcap format</a></center>';
 	} else {
 		$url = '<center><a href="base_payload.php?'.$query;
-		$url.= '&download=2&cid='.$cid.'&sid='.$sid.'&asciiclean=0">Download in pcap format</a></center>';
+		$url.= '&amp;download='.$type.'&amp;cid='.$cid.'&amp;sid='.$sid.'&amp;asciiclean=0">Download in pcap format</a></center>';
 	}
 	return $url;
 }
@@ -146,7 +141,7 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
   $_SERVER["QUERY_STRING"] = "submit=".rawurlencode($submit);
 
   $et = new EventTiming($debug_time_mode);
-  $cs = new CriteriaState("base_qry_alert.php");
+  $cs = new CriteriaState("base_qry_main.php", "&amp;new=1&amp;submit="._QUERYDBP);
   $cs->ReadState();
 
   $qs = new QueryState();
@@ -267,7 +262,7 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
   echo '
        <BLOCKQUOTE>
        <TABLE BORDER=1 width="90%">
-          <TR><TD CLASS="metatitle" WIDTH=50 ALIGN=CENTER ROWSPAN=3>Meta
+          <TR><TD CLASS="metatitle" WIDTH=50 ALIGN=CENTER ROWSPAN=4>Meta
               <TD>
                   <TABLE BORDER=1 CELLPADDING=4>
                     <TR><TD CLASS="plfieldhdr" >'._ID.' #</TD>
@@ -284,17 +279,35 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
              <TD>
                 <TABLE BORDER=1 CELLPADDING=4>
                   <TR><TD CLASS="metatitle" ALIGN=CENTER ROWSPAN=2>'._SENSOR.'</TD>
-                       <TD class="plfieldhdr">',_NAME,'</TD>
+                       <TD class="plfieldhdr">',_SENSOR.' '._ADDRESS,'</TD>
                        <TD class="plfieldhdr">'._INTERFACE.'</TD>
                        <TD class="plfieldhdr">'._FILTER.'</TD>
                   </TR>
                   <TR><TD class="plfield">'.$myrow4[0].'</TD>
-                      <TD class="plfield">'.$myrow4[1].'</TD>
+                      <TD class="plfield">'.
+		      ( ($myrow4[1] == "") ? "&nbsp;<I>"._NONE."</I>&nbsp;" : $myrow4[1] ).'</TD>
                       <TD class="plfield">'.
                       ( ($myrow4[2] == "") ? "&nbsp;<I>"._NONE."</I>&nbsp;" : $myrow4[2] ).'</TD>
                   </TR>
                  </TABLE>     
           </TR>';
+
+  if ( $resolve_IP == 1 )
+  {
+     echo '  <TR>
+              <TD>
+                <TABLE BORDER=1 CELLPADDING=4>
+                  <TR><TD CLASS="iptitle" ALIGN=CENTER ROWSPAN=2>FQDN</TD>
+                       <TD class="plfieldhdr">'._SENSOR.' '._NAME.'</TD>
+                  </TR>
+                  <TR><TD class="plfield">'.
+                      (baseGetHostByAddr($myrow4[0],
+                                        $db, $dns_cache_lifetime)).'</TD>
+                  </TR>
+                 </TABLE>     
+            </TR>';
+  }
+
   $result4->baseFreeRows();
 
   $sql4 = "SELECT acid_ag_alert.ag_id, ag_name, ag_desc ".
@@ -358,31 +371,31 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
                         <TD class="plfieldhdr">TOS</TD>
                         <TD class="plfieldhdr">'._LENGTH.'</TD>
                         <TD class="plfieldhdr">'._ID.'</TD>
-                        <TD class="plfieldhdr">D<BR>F</TD>
-                        <TD class="plfieldhdr">M<BR>F</TD>
+                        <TD class="plfieldhdr">fragment</TD>
                         <TD class="plfieldhdr">offset</TD>
                         <TD class="plfieldhdr">TTL</TD>
                         <TD class="plfieldhdr">chksum</TD></TR>';
   echo '             <TR><TD class="plfield">
-                       <A HREF="base_stat_ipaddr.php?ip='.baseLong2IP($myrow2[0]).'&netmask=32">'.
+                       <A HREF="base_stat_ipaddr.php?ip='.baseLong2IP($myrow2[0]).'&amp;netmask=32">'.
                             baseLong2IP($myrow2[0]).'</A></TD>';
   echo '                 <TD class="plfield">
-                         <A HREF="base_stat_ipaddr.php?ip='.baseLong2IP($myrow2[1]).'&netmask=32">'.
+                         <A HREF="base_stat_ipaddr.php?ip='.baseLong2IP($myrow2[1]).'&amp;netmask=32">'.
                             baseLong2IP($myrow2[1]).'</A></TD>';
   echo '                 <TD class="plfield">'.$myrow2[2].'</TD>';
   echo '                 <TD class="plfield">'.($myrow2[3] << 2).'</TD>';    /* ihl is in 32 bit words, must be multiplied by 4 to show in bytes */
   echo '                 <TD class="plfield">'.$myrow2[4].'</TD>';
   echo '                 <TD class="plfield">'.$myrow2[5].'</TD>';
   echo '                 <TD class="plfield">'.$myrow2[6].'</TD>';
-  if ( ($myrow2[7] & 2 ) != 0 )
-     echo 'X';
-  echo '                    </TD><TD class="plfield">';
-  if ( ($myrow2[7] & 1 ) != 0 )
-     echo 'X';
-  echo '                    </TD><TD class="plfield">';
-  echo '                 <TD class="plfield">'.$myrow2[8].'</TD>';
+  echo '                 <TD class="plfield">';
+  if ($myrow2[7] == 1)
+	echo 'yes';
+  else
+	echo 'no';
+  echo 							  '</TD>';
+  list( , $my_offset, ) = unpack("n", pack("S", $myrow2[8]));
+  echo '                 <TD class="plfield">'. ($my_offset * 8) .'</TD>';
   echo '                 <TD class="plfield">'.$myrow2[9].'</TD>';
-  echo '                 <TD class="plfield">'.$myrow2[10].'</TD></TR>';
+  echo '                 <TD class="plfield">'.$myrow2[10].'<BR>= 0x'.dechex($myrow2[10]).'</TD></TR>';
   echo '         </TABLE>';
 
   if ( $resolve_IP == 1 )
@@ -425,7 +438,12 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
          echo '    <TR><TD>#'.($i+1).'</TD>';
          echo '        <TD class="plfield">'.IPOption2str($myrow3[4]).'</TD>';
          echo '        <TD class="plfield">'.$myrow3[5].'</TD>';
-         echo '        <TD class="plfield">'.$myrow3[6].'</TD></TR>';             
+         echo '        <TD class="plfield">';
+         if ($myrow3[6] != "" )
+           echo $myrow3[6];
+         else
+           echo '&nbsp;';
+         echo '</TD></TR>';
      }
    }
    else
@@ -454,7 +472,7 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
 
      if ( $debug_mode > 0 ) {
 	echo "&lt;debug&gt;<BR>";
-	echo "Encoding: $myrow6[0]<BR>";
+	echo "Encoding: $encoding<BR>";
 	echo "Data header: &lt;$myrow5[0]&gt;<BR>";
 	echo "strlen: " . strlen($myrow5[0]);
 	echo "<br>Base64 decoded: &lt;" . base64_decode($myrow5[0]) . "&gt;<BR>";
@@ -475,7 +493,13 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
      }
 
      /* from here on $t is in hex format, even if original encoding was base64 */
-     if ( strlen($t) >= 24 ) {
+
+     /* "MACDAD" (ascii code in hex: 4d 41 43 44 41 44) is a key word used by
+      * sfPortscan, rather than a real MAC address; cf. 
+      * snort-2.6.0/doc/README.sfportscan
+      * snort-2.6.0/src/preprocessors/spp_sfportscan.c
+      * snort-2.6.0/src/preprocessors/flow/portscan/flowps_snort.c */
+     if ( strlen($t) >= 24 && strncmp($t, '4d41434441444d4143444144', 24) != 0) {
         $dst_mac = $t[0].$t[1].':'.$t[2].$t[3].':'.$t[4].$t[5].':'.$t[6].$t[7].':'.$t[8].$t[9].':'.$t[10].$t[11];
         $src_mac = $t[12].$t[13].':'.$t[14].$t[15].':'.$t[16].$t[17].':'.$t[18].$t[19].':'.$t[20].$t[21].':'.$t[22].$t[23];
 
@@ -543,37 +567,59 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
       echo '                <TD class="plfield">';
       if ( ($myrow2[6] & 128) != 0 )
            echo 'X';
+      else
+           echo '&nbsp;';
       echo '                    </TD><TD class="plfield">';
       if ( ($myrow2[6] & 64 ) != 0 )
            echo 'X';
+      else
+           echo '&nbsp;';
       echo '                    </TD><TD class="plfield">';
       if ( ($myrow2[6] & 32) != 0 )
            echo 'X';
+      else
+           echo '&nbsp;';
       echo '                    </TD><TD class="plfield">';
       if ( ($myrow2[6] & 16 ) != 0 )
            echo 'X';
+      else
+           echo '&nbsp;';
       echo '                    </TD><TD class="plfield">';
       if ( ($myrow2[6] & 8) != 0 )
            echo 'X';
+      else
+           echo '&nbsp;';
       echo '                    </TD><TD class="plfield">';
       if ( ($myrow2[6] & 4 ) != 0 )
            echo 'X';
+      else
+           echo '&nbsp;';
       echo '                    </TD><TD class="plfield">';
       if ( ($myrow2[6] & 2 ) != 0 )
            echo 'X';
+      else
+           echo '&nbsp;';
       echo '                    </TD><TD class="plfield">';
       if ( ($myrow2[6] & 1 ) != 0 )
            echo 'X';
+      else
+           echo '&nbsp;';
       echo '                    </TD>';
      
       echo '                <TD class="plfield">'.$myrow2[2].'</TD>';    
       echo '                <TD class="plfield">'.$myrow2[3].'</TD>';
-      echo '                <TD class="plfield">'.$myrow2[4].'</TD>';
+
+	/* data offset is in 32 bit words, cf. RFC 793, 3.1 (= p. 16), 
+	 * PrintTCPHeader() in snort-2.6.0/src/log.c
+	 * DecodeTCP() in snort-2.6.0/src/decode.c
+	 * #define TCP_OFFSET(tcph) in snort-2.6.0/src/decode.h
+	 * Database() in snort-2.6.0/src/output-plugins/spo_database.c */
+      echo '                <TD class="plfield">'. ($myrow2[4] << 2) .'</TD>';
       echo '                <TD class="plfield">'.$myrow2[5].'</TD>';
       echo '                <TD class="plfield">'.$myrow2[7].'</TD>';
       echo '                <TD class="plfield">'.$myrow2[9].'</TD>';
-      echo '                <TD class="plfield">'.$myrow2[8].'</TD></TR>';
-      echo '         </TABLE></TR></TR>';
+      echo '                <TD class="plfield">'.$myrow2[8].'<BR>=<BR>0x'.dechex($myrow2[8]).'</TD></TR>';
+      echo '         </TABLE></TR>';
       echo '  <TR>';
       echo '      <TD>';
       echo '         <TABLE BORDER=1 CELLPADDING=4>';
@@ -592,7 +638,12 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
              echo '    <TR><TD class="plfield">#'.($i+1).'</TD>';
              echo '        <TD class="plfield">'.TCPOption2str($myrow3[4]).'</TD>';
              echo '        <TD class="plfield">'.$myrow3[5].'</TD>';
-             echo '        <TD class="plfield">'.$myrow3[6].'</TD></TR>';             
+             echo '        <TD class="plfield">';
+             if ($myrow3[6] != "" )
+               echo $myrow3[6];
+             else
+               echo '&nbsp;';
+             echo '</TD></TR>';
          }
       }
       else
@@ -663,7 +714,7 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
                            <TD class="plfieldhdr">seq #</TR>';
      echo '            <TR><TD class="plfield">('.$myrow2[0].') '.ICMPType2str($myrow2[0]).'</TD>';
      echo '                <TD class="plfield">('.$myrow2[1].') '.ICMPCode2str($myrow2[0],$myrow2[1]).'</TD>';
-     echo '                <TD class="plfield">'.$myrow2[2].'</TD>';
+     echo '                <TD class="plfield">'.$myrow2[2].'<BR>=<BR>0x'. dechex($myrow2[2])  .'</TD>';
      echo '                <TD class="plfield">'.$myrow2[3].'</TD>';
      echo '                <TD class="plfield">'.$myrow2[4].'</TD></TR>';
      echo '         </TABLE>';
@@ -680,7 +731,7 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
   $result2 = $db->baseExecute($sql2);
   $myrow2 = $result2->baseFetchRow();
   $result2->baseFreeRows();
-  $payload = $myrow2[0];
+  !empty($myrow2) ? $payload = $myrow2[0] : '';
 
   echo '
         <TABLE BORDER=1 WIDTH="90%">
@@ -770,17 +821,17 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
               echo '<TR>';
               if ( $ICMPitype == "5" ) {
                  echo '<TD class="plfield">';
-                 echo '<A HREF="base_stat_ipaddr.php?ip='.$gateway.'&netmask=32" TARGET="_PL_SIP">'.$gateway.'</A></TD>';
+                 echo '<A HREF="base_stat_ipaddr.php?ip='.$gateway.'&amp;netmask=32" TARGET="_PL_SIP">'.$gateway.'</A></TD>';
                  echo '<TD class="plfield">'.baseGetHostByAddr($gateway, $db, $dns_cache_lifetime).'</TD>';
               }
               echo '<TD class="plfield">'.IPProto2Str($icmp_proto).'</TD>';
               echo '<TD class="plfield">';
-              echo '<A HREF="base_stat_ipaddr.php?ip='.$icmp_src.'&netmask=32" TARGET="_PL_SIP">'.$icmp_src.'</A></TD>';
+              echo '<A HREF="base_stat_ipaddr.php?ip='.$icmp_src.'&amp;netmask=32" TARGET="_PL_SIP">'.$icmp_src.'</A></TD>';
               echo '<TD class="plfield">'.baseGetHostByAddr($icmp_src, $db, $dns_cache_lifetime).'</TD>';
               if ( $icmp_proto == "6" || $icmp_proto == "17" )
                  echo '<TD class="plfield">'.$icmp_src_port.'</TD>';
               echo '<TD class="plfield">';
-              echo '<A HREF="base_stat_ipaddr.php?ip='.$icmp_dst.'&netmask=32" TARGET="_PL_DIP">'.$icmp_dst.'</A></TD>';
+              echo '<A HREF="base_stat_ipaddr.php?ip='.$icmp_dst.'&amp;netmask=32" TARGET="_PL_DIP">'.$icmp_dst.'</A></TD>';
               echo '<TD class="plfield">'.baseGetHostByAddr($icmp_dst, $db, $dns_cache_lifetime).'</TD>';
               if ( $icmp_proto == "6" || $icmp_proto == "17" )
                  echo '<TD class="plfield">'.$icmp_dst_port.'</TD>';
@@ -814,4 +865,5 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
 
   $et->Mark("Get Query Elements");
   $et->PrintTiming();
+  echo "</body>\r\n</html>";
 ?>
