@@ -6,7 +6,8 @@
 **
 ** (see the file 'base_main.php' for license details)
 **
-** Project Leads: Kevin Johnson <kjohnson@secureideas.net>, Joel Esler <joelesler@users.sourceforge.net>
+** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: support routines for processing criteria
@@ -17,7 +18,7 @@
 **
 ********************************************************************************
 */
-
+defined( '_BASE_INC' ) or die( 'Accessing this file directly is not allowed.' );
 include_once("$BASE_path/includes/base_signature.inc.php");
 
 function PrintCriteriaState()
@@ -107,10 +108,9 @@ function FieldRows2sql($field, $cnt, &$s_sql)
   return 0;
 }
 
-function formatTimeDigit($time_digit) 
+function FormatTimeDigit($time_digit) 
 {
-	//$int_time_digit = (int) $time_digit;
-	if(((int) $time_digit) < 10 && strlen($time_digit==1))
+	if(strlen(trim($time_digit))==1)
 		$time_digit = "0".trim($time_digit);
 	return $time_digit;
 }
@@ -124,6 +124,7 @@ function DateTimeRows2sql($field, $cnt, &$s_sql)
 {
   GLOBAL $db;
   $tmp2 = "";
+  $allempty = FALSE;
   $time_field = array("mysql" => ":", "mssql" => ":");
   $minsec = array( ">=" => "00", "<=" => "59");
 
@@ -267,8 +268,8 @@ function DateTimeRows2sql($field, $cnt, &$s_sql)
       {
          if ( isset($field[$i]) )
          {
-           if ( ($field[$i][2] != " " || $field[$i][3] != "" || $field[$i][4] != " ") && 
-               $field[$i][1] == " ")
+           if ( ($field[$i][2] != "" || $field[$i][3] != "" || $field[$i][4] != "") && 
+               $field[$i][1] == "")
               ErrorMessage("<B>"._QCERRCRITWARN."</B> "._QCERRDATETIME." '".
                             $field[$i][2]."-".$field[$i][3]."-".$field[$i][4]." ".
                             $field[$i][5].":".$field[6].":".$field[7]."' "._QCERROPERSELECT);
@@ -328,7 +329,7 @@ function FormatPayload($payload_str, $data_encode)
         for ( $i = 0; $i < strlen($payload_str); $i++ )
             $tmp = $tmp.dechex(ord($payload_str[$i]));
 
-     return $tmp;
+     return strtoupper($tmp);
   }
 
   return "";    /* should be unreachable */
@@ -791,7 +792,7 @@ if ( $layer4 == "TCP" )
   
   $proto_tmp = "";
   /* TCP Flags */
-  if ( isset($tcp_flags) )
+  if ( isset($tcp_flags) && sizeof($tcp_flags) == 8)
   {
     if ( $tcp_flags[0] == "contains" || $tcp_flags[0] == "is" )
     {
