@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: renders the HTML form to gather search criteria
@@ -289,7 +290,15 @@ function loopElements(el,level){
 						temp.onclick=showHide;
 					}else if(temp.tagName.toLowerCase() == "ul"){
 						//Hide sublevels
-						temp.style.display = "none"
+
+';
+   if ($show_expanded_query == 1)
+ echo ' 
+						temp.style.display = ""  ';
+   else
+ echo ' 
+						temp.style.display = "none"  ';
+ echo '
 						//Set class
 						temp.className= "zMenu"+level
 						//Recursive - calling self with new found element - go all the way through 
