@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Lead: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: Alert action (e.g. add to AG, delete, email,
@@ -701,7 +702,7 @@ function Action_add_new_ag_Post($action_arg, &$action_ctx, $db, &$num_alert, $ac
    {
      /* Add was successful, so redirect user to AG edit page */
      echo '<script type=text/javascript>
-            var _page = "base_ag_main.php?ag_action=edit&ag_id='.$action_ctx.'&submit=x";
+            var _page = "base_ag_main.php?ag_action=edit&amp;ag_id='.$action_ctx.'&amp;submit=x";
             window.location=_page;
           </script>';
    }
@@ -729,8 +730,8 @@ function Action_del_alert_post($action_arg, &$action_ctx, $db, &$num_alert, $act
   /* count the number of check boxes selected  */
   for ( $i = 0; $i < $action_lst_cnt ; $i++)  
   { 
-     if ($action_chk_lst[$i] > "" )
-       $sel_cnt += 1;
+     if (isset($action_chk_lst[$i]))
+       $sel_cnt++;
   }
   if ($sel_cnt > 0)       /* 1 or more check boxes selected ? */
       $num_alert -= $sel_cnt;
@@ -1259,6 +1260,7 @@ function Action_archive_alert_op($sid, $cid, &$db, $action_arg, &$ctx)
 
            if ( $sig_priority == "" )  $sig_priority = 'NULL';
            if ( $sig_rev == "" )  $sig_rev = 'NULL';
+           if ( $sig_gid == "" )  $sig_gid = 'NULL';
            
            if ( $db->baseGetDBversion() >= 107 )
                 $sql = "INSERT INTO signature (sig_name, sig_class_id, sig_priority, sig_rev, sig_sid, sig_gid) ".
@@ -1451,7 +1453,12 @@ function Action_archive_alert_op($sid, $cid, &$db, $action_arg, &$ctx)
 
 function Action_archive_alert_post($action_arg, &$action_ctx, $db, &$num_alert, $action_cnt)
 {
-  /* none */
+   /* BEGIN LOCAL FIX */
+   /* Call UpdateAlertCache to properly set cid values and make sure caches are current */ 
+   $archive_db=&$action_ctx;
+   UpdateAlertCache($archive_db);
+   UpdateAlertCache($db);
+   /* END LOCAL FIX */
 }
 
 function Action_archive_alert2_pre($action_arg, $action_param, $db)
@@ -1480,6 +1487,12 @@ function Action_archive_alert2_op($sid, $cid, &$db, $action_arg, &$ctx)
 
 function Action_archive_alert2_post($action_arg, &$action_ctx, $db, &$num_alert, $action_cnt)
 {
+  /* BEGIN LOCAL FIX */ 
+  /* Call UpdateAlertCache to properly set cid values and make sure caches are current */
+  $archive_db=&$action_ctx;
+  UpdateAlertCache($archive_db); 
+  UpdateAlertCache($db);
+  /* END LOCAL FIX */
   /* Reset the alert count that the query is re-executed to reflect the deletion */
   $num_alert -= $action_cnt;
 }
