@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Lead: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: IP DNS, whois, event cache library   
@@ -417,6 +418,10 @@ function CacheSensor($sid, $cid, $db)
 function UpdateAlertCache($db)
 {
   GLOBAL $debug_mode;
+  GLOBAL $archive_exists;
+  GLOBAL $DBlib_path, $DBtype, 
+         $archive_dbname, $archive_host, $archive_port,
+         $archive_user, $archive_password;
 
   $batch_sql = "";
   $batch_cnt = 0;
@@ -460,12 +465,45 @@ function UpdateAlertCache($db)
 
      $cid_lst->baseFreeRows();
      $ccid_lst->baseFreeRows();
+ 
+      /* BEGIN LOCAL FIX */
+ 
+      /* If there's an archive database, and this isn't it, get the MAX(cid) from there */
+      if ( ($archive_exists == 1) && (@$_COOKIE['archive'] != 1) ) { 
+        $db2 = NewBASEDBConnection($DBlib_path, $DBtype);
+        $db2->baseConnect($archive_dbname, $archive_host, $archive_port,
+                          $archive_user, $archive_password);
+        $archive_ccid_lst = $db2->baseExecute("SELECT MAX(cid) FROM acid_event WHERE sid='".$sid."'"); 
+        $archive_ccid_row = $archive_ccid_lst->baseFetchRow();
+        $archive_ccid = $archive_ccid_row[0];
+		$archive_ccid_lst->baseFreeRows();
+		$db2->baseClose();
+        if ( $archive_ccid == NULL ) $archive_ccid = 0;
+	$archive_ccid_lst->baseFreeRows();
+	$db2->baseClose();
+      } else {
+        $archive_ccid = 0; 
+      }
+ 
+      if ( $archive_ccid > $ccid ) {
+        $max_ccid = $archive_ccid;
+      } else {
+        $max_ccid = $ccid;
+      }
+ 
+      /* Fix the last_cid value for the sensor */
+      $db->baseExecute("UPDATE sensor SET last_cid=$max_ccid WHERE sid=$sid"); 
+ 
+      /* END LOCAL FIX */
   }  
 
- if ( preg_match("/base_main.php/", $_SERVER['SCRIPT_NAME']) )
-       ErrorMessage(_ADDED.$updated_cache_cnt._ALERTSCACHE, "yellow");
- else
-       ErrorMessage(_ADDED.$updated_cache_cnt._ALERTSCACHE);
+ if ( $updated_cache_cnt != 0 )
+ {
+   if ( preg_match("/base_main.php/", $_SERVER['SCRIPT_NAME']) )
+         ErrorMessage(_ADDED.$updated_cache_cnt._ALERTSCACHE, "yellow");
+   else
+         ErrorMessage(_ADDED.$updated_cache_cnt._ALERTSCACHE);
+  }
 }
 
 function DropAlertCache($db)
