@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Lead: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: Database abstraction layer
@@ -39,12 +40,13 @@ class baseCon {
      $this->DB_type = $type;
   }
 
-  function baseDBConnect($method, $database, $host, $port, $username, $password)
+  function baseDBConnect($method, $database, $host, $port, $username, $password, $force = 0)
   {
     GLOBAL $archive_dbname, $archive_host, $archive_port, $archive_user, $archive_password;
     
     // Check archive cookie to see if they want to be using the archive tables
-    if ( @$_COOKIE['archive'] == 1)
+    // and check - do we force to use specified database even if archive cookie is set
+    if ( (@$_COOKIE['archive'] == 1) && ($force != 1) )
     {
       // Connect to the archive tables
         $this->baseConnect($archive_dbname, $archive_host, $archive_port, $archive_user, $archive_password);
@@ -92,8 +94,10 @@ class baseCon {
      } 
 
      /* Set the database schema version number */
-     $sql = "SELECT vseq FROM schema"; 
+     $sql = "SELECT vseq FROM schema";
+     if ($this->DB_type == "mysql") $sql = "SELECT vseq FROM `schema`"; 
      if ($this->DB_type == "mssql") $sql = "SELECT vseq FROM [schema]";
+
      $result = $this->DB->Execute($sql);
      if ( $this->baseErrorMessage() != "" )
         $this->version = 0;
@@ -109,7 +113,7 @@ class baseCon {
         fwrite($this->sql_trace, 
               "\n--------------------------------------------------------------------------------\n");  
         fwrite($this->sql_trace, "Connect [".$this->DB_type."] ".$database."@".$host.":".$port." as ".$username."\n");
-        fwrite($this->sql_trace, "[".date ("M d Y H:i:s", time())."] ".$_SERVER["PHP_SELF"]." - db version ".$this->version);
+        fwrite($this->sql_trace, "[".date ("M d Y H:i:s", time())."] ".$_SERVER["SCRIPT_NAME"]." - db version ".$this->version);
         fwrite($this->sql_trace, 
               "\n--------------------------------------------------------------------------------\n\n");
         fflush($this->sql_trace);
@@ -152,8 +156,9 @@ class baseCon {
      } 
 
      /* Set the database schema version number */
-     $sql = "SELECT vseq FROM schema"; 
+     $sql = "SELECT vseq FROM `schema`"; 
      if ($this->DB_type == "mssql") $sql = "SELECT vseq FROM [schema]";
+     if ($this->DB_type == "postgres") $sql = "SELECT vseq FROM schema";
      $result = $this->DB->Execute($sql);
      if ( $this->baseErrorMessage() != "" )
         $this->version = 0;
@@ -169,7 +174,7 @@ class baseCon {
         fwrite($this->sql_trace, 
               "\n--------------------------------------------------------------------------------\n");  
         fwrite($this->sql_trace, "PConnect [".$this->DB_type."] ".$database."@".$host.":".$port." as ".$username."\n");
-        fwrite($this->sql_trace, "[".date ("M d Y H:i:s", time())."] ".$_SERVER["PHP_SELF"]." - db version ".$this->version);
+        fwrite($this->sql_trace, "[".date ("M d Y H:i:s", time())."] ".$_SERVER["SCRIPT_NAME"]." - db version ".$this->version);
         fwrite($this->sql_trace, 
               "\n--------------------------------------------------------------------------------\n\n");
         fflush($this->sql_trace);
@@ -188,17 +193,8 @@ class baseCon {
      GLOBAL $debug_mode, $sql_trace_mode;
 
      /* ** Begin DB specific SQL fix-up ** */
-
      if ($this->DB_type == "mssql")
-     {
         $sql = eregi_replace("''", "NULL", $sql);
-     }
-
-    // Fix for the SQL injection attack
-    $sql_save = $sql;    
-    $sql = eregi_replace(";", "", $sql);
-
-    /* ** End SQL fix-up ** */
 
      $this->lastSQL = $sql;
      $limit_str = "";
@@ -274,97 +270,18 @@ class baseCon {
 
   function baseTableExists($table)
   {
-     $table_list = $this->DB->MetaTables();
-
-     if ( $table_list != "" )
-     {
-       if( $this->DB_type == 'oci8' ) {
-         for ( $i = 0; $i < sizeof($table_list); $i++ )
-         {
-          if ( $table_list[$i] == strtoupper($table) )
-             return 1;
-         }
-       }
-       else {
-         for ( $i = 0; $i < sizeof($table_list); $i++ )
-         {
-          if ( $table_list[$i] == $table )
-             return 1;
-         }
-       }
-     }
-
-     return 0;
+     if ( in_array($table, $this->DB->MetaTables()) )
+        return 1;
+     else 
+        return 0;
   }
 
-  function baseIndexExists($table, $field)
+  function baseIndexExists($table, $index_name)
   {
-     if ( ($this->DB_type == "mysql") || ($this->DB_type == "mysqlt") ||
-          ($this->DB_type == "maxsql") )
-     {
-        $sql = "SHOW INDEX FROM ".$table; 
-        $result = $this->DB->Execute($sql);
-        if ( $this->baseErrorMessage() != "" )
-           return 0;
-        else
-        {
-           $num = $result->RecordCount();
-           $done = 0;
-           for ($i = 0; $i < $num && !$done; $i++)
-           {
-               $myrow = $result->fields;
-
-               if ( $myrow[4] == $field )
-                  $done = 1;
- 
-               $result->MoveNext();
-            }
-            $result->Close();
-        }
- 
-        return $done;
-     }
-     if( $this->DB_type == "oci8" ) {
-       $index_list = $this->DB->MetaIndexes( strtoupper( $table ) );
-       if ( $index_list != "" ) {
-         foreach( array_keys ($index_list) as $index ) {
-	   if( $index_list[ $index ][ 'columns' ][0] == strtoupper($field) )
-            return 1;
-         }
-       }
-     }
-     else if( $this->DB_type == "oci8" ) {
-       $index_list = $this->DB->MetaIndexes( strtoupper( $table ) );
-       if ( $index_list != "" ) {
-         foreach( array_keys ($index_list) as $index ) {
-	   if( $index_list[ $index ][ 'columns' ][0] == strtoupper($field) )
-            return 1;
-         }
-       }
-     }
-     /*  Work on the postgres stuff -- Kevin
-    else if ( ($this->DB_type == "postgres") )
-     {
-        $sql = "SELECT * FROM pg_indexes WHERE indexname='". $table ."';";
-        $result = $this->DB->Execute($sql);
-        if ( $this->baseErrorMessage() != "" )
-           return 0;
-        else
-        {
-          $num = $result->RecordCount();
-          $done = 0;
-          if ( $num != 0 )
-          {
-            $done = 1;
-          }
-          
-          $result->Close();
-        }
-        
-        return $done;
-     } */
-     else
-        return -1;
+     if ( in_array($index_name, $this->DB->MetaIndexes($table)) )
+        return 1;
+     else 
+        return 0;
   }
 
   function baseInsertID()
@@ -678,4 +595,20 @@ function RepairDBTables($db)
     I will be searching to see where it was called from if at all */
 }
 
+function ClearDataTables($db)
+{
+  $db->baseExecute("DELETE FROM acid_event");
+  $db->baseExecute("DELETE FROM data");
+  $db->baseExecute("DELETE FROM event");
+  $db->baseExecute("DELETE FROM icmphdr");
+  $db->baseExecute("DELETE FROM iphdr");
+  $db->baseExecute("DELETE FROM reference");
+  $db->baseExecute("DELETE FROM sensor");
+  $db->baseExecute("DELETE FROM sig_class");
+  $db->baseExecute("DELETE FROM sig_reference");
+  $db->baseExecute("DELETE FROM signature");
+  $db->baseExecute("DELETE FROM tcphdr");
+  $db->baseExecute("DELETE FROM udphdr");
+} 
+
 ?>
