@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Lead: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: Handles signatures and references in the 
@@ -125,75 +126,84 @@ function GetSingleSignatureReference($ref_system, $ref_tag, $style)
 function GetSignatureReference($sig_id, $db, $style)
 {
    $ref = "";
-
-   $temp_sql = "SELECT ref_seq, ref_id FROM sig_reference WHERE sig_id='".$sig_id."'";
-   $tmp_sig_ref = $db->baseExecute($temp_sql);
-
-   if ( $tmp_sig_ref )
+   GLOBAL $BASE_display_sig_links;
+   
+   if ( $BASE_display_sig_links == 1)
    {
-      $num_references = $tmp_sig_ref->baseRecordCount();
-      for ( $i = 0; $i < $num_references; $i++)
+      $temp_sql = "SELECT ref_seq, ref_id FROM sig_reference WHERE sig_id='".$sig_id."'";
+      $tmp_sig_ref = $db->baseExecute($temp_sql);
+   
+      if ( $tmp_sig_ref )
       {
-         $mysig_ref = $tmp_sig_ref->baseFetchRow();
-
-         $temp_sql = "SELECT ref_system_id, ref_tag FROM reference WHERE ref_id='".$mysig_ref[1]."'";
-         $tmp_ref_tag = $db->baseExecute($temp_sql);
-
-         if ( $tmp_ref_tag )
+         $num_references = $tmp_sig_ref->baseRecordCount();
+         for ( $i = 0; $i < $num_references; $i++)
          {
-            $myrow = $tmp_ref_tag->baseFetchRow();
-            $ref_tag = $myrow[1];
-            $ref_system = GetRefSystemName($myrow[0], $db);
+            $mysig_ref = $tmp_sig_ref->baseFetchRow();
+   
+            $temp_sql = "SELECT ref_system_id, ref_tag FROM reference WHERE ref_id='".$mysig_ref[1]."'";
+            $tmp_ref_tag = $db->baseExecute($temp_sql);
+   
+            if ( $tmp_ref_tag )
+            {
+               $myrow = $tmp_ref_tag->baseFetchRow();
+               $ref_tag = $myrow[1];
+               $ref_system = GetRefSystemName($myrow[0], $db);
+            }
+   
+            $ref = $ref.GetSingleSignatureReference($ref_system, $ref_tag, $style);
+   
+            /* Automatically add an ICAT reference is a CVE reference exists */
+            if ( $ref_system == "cve" )
+                $ref = $ref.GetSingleSignatureReference("icat", $ref_tag, $style);
+          
+            $tmp_ref_tag->baseFreeRows();
          }
-
-         $ref = $ref.GetSingleSignatureReference($ref_system, $ref_tag, $style);
-
-         /* Automatically add an ICAT reference is a CVE reference exists */
-         if ( $ref_system == "cve" )
-             $ref = $ref.GetSingleSignatureReference("icat", $ref_tag, $style);
-       
-         $tmp_ref_tag->baseFreeRows();
+         $tmp_sig_ref->baseFreeRows();
       }
-      $tmp_sig_ref->baseFreeRows();
-   }
-
-   if ( $db->baseGetDBversion() >= 103 )
-   {
-      if ( $db->baseGetDBversion() >= 107 )
-         $tmp_sql = "SELECT sig_sid, sig_gid FROM signature WHERE sig_id='".$sig_id."'";
-      else
-         $tmp_sql = "SELECT sig_sid FROM signature WHERE sig_id='".$sig_id."'";
-
-      $tmp_sig_sid = $db->baseExecute($tmp_sql);
-
-      if ( $tmp_sig_sid )
+   
+      if ( $db->baseGetDBversion() >= 103 )
       {
-         $myrow = $tmp_sig_sid->baseFetchRow();
-         $sig_sid = $myrow[0];
          if ( $db->baseGetDBversion() >= 107 )
-            $sig_gid = $myrow[1];
-
+            $tmp_sql = "SELECT sig_sid, sig_gid FROM signature WHERE sig_id='".$sig_id."'";
+         else
+            $tmp_sql = "SELECT sig_sid FROM signature WHERE sig_id='".$sig_id."'";
+   
+         $tmp_sig_sid = $db->baseExecute($tmp_sql);
+   
+         if ( $tmp_sig_sid )
+         {
+            $myrow = $tmp_sig_sid->baseFetchRow();
+            $sig_sid = $myrow[0];
+            if ( $db->baseGetDBversion() >= 107 )
+               $sig_gid = $myrow[1];
+   
+         }
       }
-   }
-   else
-      $sig_sid = "";
-
-   $href = "";
-
-   /* xxx jl: provided, that there is a subdirectory "signatures/" in $BASE_urlpath */
-   if ( ( is_numeric($sig_id) ) && ($sig_sid >= 103) ) {
-      $ref = $ref.GetSingleSignatureReference("local", $sig_sid, $style);
-   }
-
-
-   /* snort.org should be documenting all official signatures,
-    * so automatically add a link
-    */
-   if ( $sig_sid != "") {
-      if ( $db->baseGetDBversion() >= 107 )
-         $ref = $ref.GetSingleSignatureReference("snort", $sig_gid .':'. $sig_sid, $style);
       else
-         $ref = $ref.GetSingleSignatureReference("snort", $sig_sid, $style);
+         $sig_sid = "";
+   
+      $href = "";
+   
+      /* xxx jl: provided, that there is a subdirectory "signatures/" in $BASE_urlpath */
+      if ( ( is_numeric($sig_id) ) && ($sig_sid >= 103) ) {
+         $ref = $ref.GetSingleSignatureReference("local", $sig_sid, $style);
+      }
+   
+   
+      /* snort.org should be documenting all official signatures,
+       * so automatically add a link
+       */
+      if ( $sig_sid != "") {
+         if ( $db->baseGetDBversion() >= 107 )
+	    /* Hack to finx blank gid from barnyard -- Kevin Johnson */
+	    if ( $sig_gid != "") {
+            	$ref = $ref.GetSingleSignatureReference("snort", $sig_gid .':'. $sig_sid, $style);
+	    } else {
+		$ref = $ref.GetSingleSignatureReference("snort", $sig_sid, $style);
+	    }
+         else
+            $ref = $ref.GetSingleSignatureReference("snort", $sig_sid, $style);
+      }
    }
 
    return $ref;
@@ -233,7 +243,7 @@ function BuildSigLookup($signature, $style)
 
       /* create hyperlink for IP addresses in portscan alerts */
       $msg = preg_replace("/([0-9]*\.[0-9]*\.[0-9]*\.[0-9]*)/",
-                          "<A HREF=\"base_stat_ipaddr.php?ip=\\1&netmask=32\">\\1</A>",
+                          "<A HREF=\"base_stat_ipaddr.php?ip=\\1&amp;netmask=32\">\\1</A>",
                           $msg);
   }
 
