@@ -6,7 +6,8 @@
 **
 ** (see the file 'base_main.php' for license details)
 **
-** Project Leads: Kevin Johnson <kjohnson@secureideas.net>, Joel Esler <joelesler@users.sourceforge.net>
+** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: Norwegian language file
@@ -14,7 +15,7 @@
 ** Estimated completion status: 60% 
 **
 ********************************************************************************
-** Authors: Ole-Martin Bkkeli (olebakk@pdapath.com)
+** Authors: Ole-Martin Bkkeli  (olebakk@pdapath.com)
 ********************************************************************************
 ** Kevin Johnson <kjohnson@secureideas.net
 ** Joel Esler <joelesler@users.sourceforge.net>
@@ -424,7 +425,7 @@ DEFINE('_ERRPHPMSSQLSUP','<B>PHP build incomplete</B>: <FONT>the prerequisite MS
                    read the alert database was not built into PHP.  
                    Please recompile PHP with the necessary library (<CODE>--enable-mssql</CODE>)</FONT>');
 DEFINE('_ERRPHPORACLESUP','<B>PHP build incomplete</B>: <FONT>the prerequisite Oracle support required to 
-                   read the alert database was not built into PHP.  
+                   read the alert database was not built into PHP.');
 DEFINE('_CHARTTYPE','Chart Type:'); //NEW
 DEFINE('_CHARTTYPES','{ chart type }'); //NEW
 DEFINE('_CHARTPERIOD','Chart Period:'); //NEW
@@ -443,7 +444,6 @@ DEFINE('_CHARTDAY','{dia}'); //NEW
 DEFINE('_CHARTMONTH','{mês}'); //NEW
 DEFINE('_GRAPHALERTS','Graph Alerts'); //NEW
 DEFINE('_AXISCONTROLS','X / Y AXIS CONTROLS'); //NEW
-                   Please recompile PHP with the necessary library (<CODE>--with-oci8</CODE>)</FONT>');
 
 //base_graph_form.php
 DEFINE('_CHARTTITLE','Chart Title:');
