@@ -6,7 +6,8 @@
 **
 ** (see the file 'base_main.php' for license details)
 **
-** Project Leads: Kevin Johnson <kjohnson@secureideas.net>, Joel Esler <joelesler@users.sourceforge.net>
+** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: Russian language file
@@ -31,7 +32,7 @@ DEFINE('_LOCALESTR3', 'english'); //NEW
 DEFINE('_STRFTIMEFORMAT','%a %B %d, %Y %H:%M:%S'); //NEW - see strftime() sintax
 
 //  
-DEFINE('_CHARSET','UTF-8');
+DEFINE('_CHARSET','windows-1251');
 DEFINE('_TITLE','     (BASE) '.$BASE_installID);
 DEFINE('_FRMLOGIN',':');
 DEFINE('_FRMPWD',':');
