@@ -6,8 +6,8 @@
 **
 ** (see the file 'base_main.php' for license details)
 **
-** Project Leads: Kevin Johnson <kjohnson@secureideas.net>, Joel Esler 
-<joelesler@users.sourceforge.net>
+** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: English language file
